@@ -10,7 +10,7 @@ void DiffWidgetTests::test_scrollbarAtTopOnOpen()
 {
     QFile f(QStringLiteral(":/katetest/test.diff"));
     QVERIFY(f.open(QFile::ReadOnly));
-    const auto diff = f.readAll();
+    const QByteArray diff = f.readAll();
 
     DiffWidget dw(DiffParams{});
     dw.show();
