@@ -75,6 +75,7 @@ public:
 public:
     void openUrl(const QUrl &url);
     void openUrlOrProject(const QUrl &url);
+    void openRecent(const QUrl &url);
     void addPositionToHistory(const QUrl &url, KTextEditor::Cursor pos);
 
 public:
@@ -127,9 +128,6 @@ public:
     bool deleteView(KTextEditor::View *view);
 
 private:
-    void moveViewtoSplit(KTextEditor::View *view);
-    void moveViewtoStack(KTextEditor::View *view);
-
     /* Save the configuration of a single splitter.
      * If child splitters are found, it calls it self with those as the argument.
      * If a viewspace child is found, it is asked to save its filelist.
@@ -221,7 +219,7 @@ public:
     /**
      * Will tell you whether or not all Scroll Sync indicators are to be displayed
      */
-    bool hasScrollSync();
+    bool hasScrollSync() const;
 
     /**
      * Will iterate over all viewspaces and show/hide the Scroll Sync indicators
@@ -420,7 +418,7 @@ private:
          */
         QHash<KTextEditor::View *, ScrollBarInfo> viewScrollInfo;
 
-        ScrollBarInfo getViewScrollBarInfo(KTextEditor::View *view);
+        ScrollBarInfo getViewScrollBarInfo(KTextEditor::View *view) const;
     } m_scrollSynchronisation;
 
     /**
